@@ -215,7 +215,7 @@ def solve_model(
     if "warmstart" in solve_kwargs.keys() and solver in ["glpk", "cbc"]:
         if solve_kwargs.pop("warmstart") is True:
             exceptions.warn(
-                "The chosen solver, {}, does not suport warmstart, which may "
+                "The chosen solver, {}, does not support warmstart, which may "
                 "impact performance.".format(solver)
             )
 
@@ -267,6 +267,7 @@ def get_result_array(backend_model, model_data):
     the backend (instead of being passed by calliope.Model().inputs) are also
     added to calliope.Model()._model_data in-place.
     """
+
     all_variables = {
         i.name: get_var(backend_model, i.name)
         for i in backend_model.component_objects()
