@@ -59,6 +59,15 @@ def get_previous_timestep(timesteps, timestep):
     return timesteps.at(timesteps.ord(timestep) - 1)
 
 
+def get_depreciation_rate(backend_model, idx):
+    """Safely extract depreciation rate data"""
+    depreciation_rates = getattr(backend_model, "cost_depreciation_rate", None)
+    if depreciation_rates is not None and idx in depreciation_rates.index_set():
+        return depreciation_rates[idx]
+    else:
+        return 1
+
+
 @memoize
 def get_loc_tech_carriers(backend_model, loc_carrier):
     """
@@ -173,9 +182,17 @@ def get_var(backend_model, var, dims=None, sparse=False, expr=False):
     if result.empty:
         raise exceptions.BackendError("Variable {} has no data.".format(var))
 
-    result = result.rename_axis(index=dims)
+    result_with_dim_names = result.rename_axis(index=dims)
 
-    return xr.DataArray.from_series(result)
+    da = xr.DataArray.from_series(result_with_dim_names)
+
+    # Order of dimension set items is sorted by pd.Series above and may no longer match
+    # the input calliope data set order. So we reorder the array dimensions here.
+    da_resorted = da.reindex(
+        **{dim: getattr(backend_model, dim)._ordered_values for dim in dims}
+    )
+
+    return da_resorted
 
 
 @memoize
@@ -315,7 +332,7 @@ def string_to_datetime(
         if attr == "coords" and set_name in model_data:
             model_data.coords[set_name] = model_data[set_name].astype("datetime64[ns]")
         elif set_name in model_data:
-            model_data[set_name] = (
-                model_data[set_name].fillna(pd.NaT).astype("datetime64[ns]")
+            model_data[set_name] = xr.apply_ufunc(
+                pd.to_datetime, model_data[set_name], keep_attrs=True
             )
     return model_data
