@@ -187,9 +187,21 @@ def run_spores(
     def _cap_loc_score_default(results):
         # Define default scoring function, based on integer scoring method
         # TODO: make it possible to point to a custom function instead of this one
-        cap_loc_score = xr.where(results.energy_cap > 1e-3, 100, 0).loc[
-            {"loc_techs": results.loc_techs_investment_cost}
-        ]
+
+        # First, we ensure that we don't erroneously score techs that have to be there no matter what.
+        if "energy_cap_min" in model_data.data_vars.keys():
+            min_cap = model_data.energy_cap_min.fillna(0)
+        else:
+            min_cap = 0
+
+        if "energy_cap_equals" in model_data.data_vars.keys():
+            forced_energy_cap = model_data.energy_cap_equals.fillna(min_cap)
+        else:
+            forced_energy_cap = min_cap
+
+        cap_loc_score = xr.where(
+            results.energy_cap - forced_energy_cap > 1e-3, 100, 0
+        ).loc[{"loc_techs": results.loc_techs_investment_cost}]
         return cap_loc_score.to_series().rename_axis(index="loc_techs_investment_cost")
 
     # Define function to update "spores_score" after each iteration of the method
@@ -309,10 +321,6 @@ def run_spores(
 
     _error_on_malformed_input()
 
-    if backend_rerun:
-        model_data = _combine_spores_results_and_inputs(
-            backend_rerun, xr.Dataset(), 0, model_data=model_data
-        )
     run_config = UpdateObserverDict(
         initial_yaml_string=model_data.attrs["run_config"],
         name="run_config",
@@ -320,6 +328,14 @@ def run_spores(
     )
 
     spores_config = run_config["spores_options"]
+
+    init_spore = _initialise_spores_number()
+
+    if backend_rerun:
+        model_data = _combine_spores_results_and_inputs(
+            backend_rerun, xr.Dataset(), init_spore, model_data=model_data
+        )
+
     if "spores" in model_data.dims and model_data.spores.size == 1:
         model_data = model_data.squeeze("spores")
 
@@ -334,8 +350,6 @@ def run_spores(
     if build_only:
         return results, backend_model, opt
 
-    init_spore = _initialise_spores_number()
-
     if spores_config["skip_cost_op"]:
         cumulative_spores_scores = init_spores_scores.copy()
         _update_to_spores_objective(backend_model)
@@ -431,6 +445,17 @@ def run_operate(model_data, timings, backend, build_only):
         comment="Backend: starting model run in operational mode",
     )
 
+    def _ensure_positive(da: xr.DataArray) -> xr.DataArray:
+        if (da < 0).any():
+            most_negative = da.min().item()
+            exceptions.print_warnings_and_raise_errors(
+                warnings=[
+                    f"Found negative values for array '{da.name}' as low as {most_negative:.0E}. "
+                    "All negative values will be clipped to zero to continue operation mode"
+                ]
+            )
+        return da.clip(min=0.0, keep_attrs=True)
+
     defaults = UpdateObserverDict(
         initial_yaml_string=model_data.attrs["defaults"],
         name="defaults",
@@ -581,7 +606,7 @@ def run_operate(model_data, timings, backend, build_only):
 
         # Update relevent Pyomo Params in intermediate instances
         else:
-            warmstart = True
+            warmstart = False if solver in ["glpk", "cbc"] else True
             end_timestep = horizon_ends.index[i]
             timesteps = slice(start_timestep, end_timestep)
             window_model_data = model_data.loc[dict(timesteps=timesteps)]
@@ -619,7 +644,7 @@ def run_operate(model_data, timings, backend, build_only):
                 comment="Backend: iteration {}: sending model to solver".format(i + 1),
             )
             # After iteration 1, warmstart = True, which should speed up the process
-            # Note: Warmstart isn't possible with GLPK (dealt with later on)
+            # Note: Warmstart isn't possible with GLPK or CBC (dealt with later on)
             _results, _opt = backend.solve_model(
                 backend_model,
                 solver=solver,
@@ -664,12 +689,14 @@ def run_operate(model_data, timings, backend, build_only):
                         "timesteps"
                     )
                     / model_data.storage_cap
-                )
+                ).rename("storage_initial")
                 model_data["storage_initial"].loc[
                     storage_initial.coords
                 ] = storage_initial.values
+
+                storage_initial_no_negative = _ensure_positive(storage_initial)
                 backend_model.storage_initial.store_values(
-                    storage_initial.to_series().dropna().to_dict()
+                    storage_initial_no_negative.to_series().dropna().to_dict()
                 )
 
             # Set up total operated units for the next iteration
