@@ -11,8 +11,9 @@ time-varying parameters.
 """
 
 import collections
+import io
 
-import ruamel.yaml
+import ruamel.yaml as ruamel_yaml
 import xarray as xr
 import numpy as np
 import pandas as pd
@@ -243,7 +244,10 @@ def costs_to_dataset(model_run):
         """
         return the set of loc_techs over which the given cost should be built
         """
-        if any(i in cost for i in ["_cap", "depreciation_rate", "purchase", "area"]):
+        if any(
+            i in cost
+            for i in ["_cap", "depreciation_rate", "purchase", "area", "om_annual"]
+        ):
             return "loc_techs_investment_cost"
         elif any(i in cost for i in ["om_", "export"]):
             return "loc_techs_om_cost"
@@ -537,18 +541,22 @@ def add_attributes(model_run):
             ]
         else:
             default_group_constraint_dict["group_" + k] = k_default
-
-    attr_dict["defaults"] = ruamel.yaml.dump(
+    yaml = ruamel_yaml.YAML()
+    stream = io.StringIO()
+    yaml.dump(
         {
             **default_tech_dict["constraints"],
             **{
                 "cost_{}".format(k): v
                 for k, v in default_tech_dict["costs"]["default_cost"].items()
             },
+            **{"cost_depreciation_rate": 1},  # we generate this parameter internally
             **default_location_dict,
             **default_group_constraint_dict,
-        }
+        },
+        stream,
     )
+    attr_dict["defaults"] = stream.getvalue()
 
     return attr_dict
 
@@ -569,9 +577,12 @@ def update_dtypes(model_data):
                 | no_nans.isin([True, False])
             ).all():
                 # Turn to bool
-                model_data[var_name] = (
-                    var.isin(["True", "1"]) | var.isin([1]) | var.isin([True])
-                )
+                if var.dtype.kind == "U":
+                    model_data[var_name] = var.isin(["True", "1"])
+                else:
+                    model_data[var_name] = (
+                        var.isin(["True", "1"]) | var.isin([1]) | var.isin([True])
+                    )
             else:
                 try:
                     model_data[var_name] = var.astype(int, copy=False)
