@@ -16,6 +16,9 @@ from calliope.test.common.util import build_test_model as build_model
 from calliope.test.common.util import constraint_sets, defaults, check_error_or_warning
 
 
+@pytest.mark.filterwarnings(
+    "ignore:(?s).*Cost classes `{'monetary'}` are defined in the objective options but not defined elsewhere in the model:calliope.exceptions.ModelWarning"
+)
 class TestModelRun:
     def test_model_from_dict(self):
         """
@@ -545,6 +548,9 @@ class TestModelRun:
             )
 
 
+@pytest.mark.filterwarnings(
+    "ignore:(?s).*Cost classes `{'monetary'}` are defined in the objective options but not defined elsewhere in the model:calliope.exceptions.ModelWarning"
+)
 class TestChecks:
     def test_unrecognised_config_keys(self):
         """
@@ -627,6 +633,9 @@ class TestChecks:
             warn, "spores run mode is selected, but a number of 0 spores is requested"
         )
 
+    @pytest.mark.filterwarnings(
+        "ignore:(?s).*Monetary cost class with a weight of 1 is still included in the objective:calliope.exceptions.ModelWarning"
+    )
     def test_non_string_score_cost_class(self):
         """
         Check that the score_cost_class for spores scoring is a string
@@ -640,6 +649,9 @@ class TestChecks:
             excinfo, "`run.spores_options.score_cost_class` must be a string"
         )
 
+    @pytest.mark.filterwarnings(
+        "ignore:(?s).*Monetary cost class with a weight of 1 is still included in the objective:calliope.exceptions.ModelWarning"
+    )
     def test_no_spore_group_constraint(self):
         """
         Ensure an error is raised if pointing to a non-existent group constraint
@@ -1123,6 +1135,9 @@ class TestChecks:
                 override_dict=override(param), scenario="simple_storage,one_day"
             )
 
+    @pytest.mark.filterwarnings(
+        "ignore:(?s).*Updated from coordinate system.*:calliope.exceptions.ModelWarning"
+    )
     def test_incorrect_location_coordinates(self):
         """
         Either all or no locations must have `coordinates` defined and, if all
@@ -1257,7 +1272,7 @@ class TestChecks:
                     heat: 1.0
             """
         )
-        with pytest.warns(None) as excinfo:
+        with pytest.warns() as excinfo:
             build_model(
                 override_dict=override, scenario="simple_conversion_plus,one_day"
             )
@@ -1276,14 +1291,12 @@ class TestChecks:
                 carrier_out.heat: file=carrier_ratio.csv
             """
         )
-        with pytest.warns(None) as excinfo:
-            build_model(
-                override_dict=override, scenario="simple_conversion_plus,one_day"
-            )
 
-        assert "Cannot load data from file for configuration" not in [
-            str(i) for i in excinfo.list
-        ]
+        model = build_model(
+            override_dict=override, scenario="simple_conversion_plus,one_day"
+        )
+
+        assert "timesteps" in model._model_data.carrier_ratios.dims
 
     @pytest.mark.filterwarnings("ignore:(?s).*Integer:calliope.exceptions.ModelWarning")
     def test_milp_constraints(self):
@@ -1563,6 +1576,9 @@ class TestChecks:
             "storage_discharge_depth is currently not allowed when time clustering is active.",
         )
 
+
+class TestChecksWithWarning:
+    # This warning is ignored in the main class since it comes up on almost every function
     def test_warn_on_undefined_cost_classes(self):
 
         with pytest.warns(exceptions.ModelWarning) as warn:
@@ -1577,6 +1593,9 @@ class TestChecks:
         )
 
 
+@pytest.mark.filterwarnings(
+    "ignore:(?s).*Cost classes `{'monetary'}` are defined in the objective options but not defined elsewhere in the model:calliope.exceptions.ModelWarning"
+)
 class TestDataset:
 
     # FIXME: What are we testing here?
@@ -1586,19 +1605,20 @@ class TestDataset:
         """
 
     @pytest.mark.parametrize(
-        "model,expected_constraint_set",
+        "model_name,expected_constraint_set",
         [
-            (calliope.examples.national_scale(), constraint_sets["model_national"]),
-            (calliope.examples.urban_scale(), constraint_sets["model_urban"]),
-            (calliope.examples.milp(), constraint_sets["model_milp"]),
+            ("national_scale", constraint_sets["model_national"]),
+            ("urban_scale", constraint_sets["model_urban"]),
+            ("milp", constraint_sets["model_milp"]),
         ],
     )
     @pytest.mark.filterwarnings("ignore:(?s).*Integer:calliope.exceptions.ModelWarning")
-    def test_unassigned_sets(self, model, expected_constraint_set):
+    def test_unassigned_sets(self, model_name, expected_constraint_set):
         """
         Check that all sets in which there are possible loc:techs are assigned
         and have been filled
         """
+        model = getattr(calliope.examples, model_name)()
         for set_name, set_vals in model._model_data.coords.items():
             if "constraint" in set_name:
                 assert set(set_vals.values) == set(expected_constraint_set[set_name])
@@ -1627,6 +1647,20 @@ class TestDataset:
         with pytest.raises(exceptions.ModelError):
             build_model(override_dict=override, scenario="simple_storage,one_day")
 
+    @pytest.mark.parametrize(
+        "scenario",
+        ["om_annual_costs_with_depreciation", "om_annual_costs_without_depreciation"],
+    )
+    def test_om_annual_without_depreciation_captured_in_set(self, scenario):
+        """
+        It should be possible to have loc_techs_investment without depreciation_rate
+        if only defining om_annual for a technology.
+        """
+        m = build_model({}, f"simple_supply,two_hours,{scenario}")
+
+        assert "0::test_supply_elec" in m._model_data.loc_techs_investment_cost
+        assert "depreciation_rate" not in m._model_data.data_vars.keys()
+
     # FIXME: What are the *required* arrays?
     def test_missing_array(self):
         """
